// Class: RowMajorEnvIterator
//
// Author: Alyce Brady
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;
import java.util.Iterator;

/**
 *  Environment-Based Applications:<br>
 *
 *    A RowMajorEnvIterator object provides an iterator that
 *    steps through the locations of a BoundedEnv object in
 *    row-major order.  It iterates through the locations and
 *    processes the rows of the environment, from 0 to R - 1,
 *    where R is the number of rows in the environment.  As
 *    part of processing each row, it traverses through the
 *    columns of that row, from 0 to C - 1, where C is the
 *    number of columns in the environment.
 *
 *  @author Alyce Brady
 *  @version 1 September 2002
 *  @see Environment
 *  @see Location
 **/
public class RowMajorEnvIterator extends EnvIterator
{
    /** Constructs an iterator object that steps through an
     *  environment.
     *  @param environment     environment to iterate through
     **/
    public RowMajorEnvIterator(BoundedEnv environment)
    {
        super(environment);
    }

    /** Helper Method: Finds next location for iterator.
     **/
    protected Location findNextLocation()
    {
        // Get the "current" next location.
        Location loc = nextLocation();

        // Find the location after the "current" next location.
        int nextCol = loc.col() + 1;
        if ( nextCol < environment().numCols() )
            return new Location(loc.row(), nextCol);
        else
            return new Location(loc.row() + 1, 0);
    }

}
